<?php

/**
 * @file
 * Page callbacks that are registered in viewsforms_menu().
 */

/**
 * Menu callback to load a viewsform via AJAX.
 * 
 * @see views_ajax()
 * @see http://drupal.org/node/331941 
 *   Doing AHAH Correctly in Drupal 6 and beyond
 */
function viewsforms_ahah($field_name) {
  $response = new stdClass();
  $response->status = FALSE;
  $response->data = '';
  
  if (empty($field_name) || empty($_POST['form_build_id'])) {
    $response->data = 'Invalid request';
    drupal_json($response);
    return;
  }

  // We're starting in step #3, preparing for #4.
  $form_state = array('storage' => NULL, 'submitted' => FALSE);
  $form_build_id = $_POST['form_build_id'];
  // Step #4.
  $form = form_get_cache($form_build_id, $form_state);

  // Preparing for #5.
  $args = isset($form['#parameters']) ? $form['#parameters'] : array();
  $form_id = array_shift($args);
  $form['#post'] = $_POST;
  $form['#programmed'] = $form['#redirect'] = FALSE;  

  // Step #5.
  drupal_process_form($form_id, $form, $form_state);
  
  // Step #6 and #7 and #8.
  if (!empty($form_state['rebuild']) || !empty($form_state['storage'])) {
    $form = drupal_rebuild_form($form_id, $form_state, $args, $form_build_id);
  }

  // Step #9. Pick our piece of the form and render it.
  $parents = explode('-', $field_name);
  $viewsform = &$form;
  foreach ($parents as $name) {
    $viewsform = &$viewsform[$name];
  }

  $viewsform['#no_wrapper'] = TRUE;
  $response->data = theme('status_messages');
  $response->data .= drupal_render($viewsform);
  //$response->data .= '<pre>'. print_r($form, 1) . '</pre>';
  $javascript = drupal_add_js(NULL, NULL);
  if (isset($javascript['setting'])) {
    $response->data .= '<script type="text/javascript">jQuery.extend(Drupal.settings, '. drupal_to_js(call_user_func_array('array_merge_recursive', $javascript['setting'])) .');</script>';
    //$response->settings = array_merge_recursive($javascript['setting']);
  }
  
  $response->status = TRUE;
  // Final rendering callback.
  drupal_json($response);
}